---
title: SetState
description: JSON Schema for the SetState action.
---

Set a client-side state variable. No server round-trip.

```json
{
  "type": "object",
  "properties": {
    "action": {
      "const": "setState",
      "default": "setState",
      "type": "string"
    },
    "key": {
      "description": "State key or dot-path to set",
      "type": "string"
    },
    "value": {
      "description": "Value to set."
    }
  },
  "required": [
    "action",
    "key",
    "value"
  ]
}
```
